@@ -46,6 +46,12 @@ GtkEpgWidget::GtkEpgWidget(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Buil
 	builder->get_widget("button_epg_next", button);
 	button->signal_clicked().connect(sigc::mem_fun(*this, &GtkEpgWidget::next));
 
+	builder->get_widget("button_epg_previous_day", button);
+	button->signal_clicked().connect(sigc::mem_fun(*this, &GtkEpgWidget::previous_day));
+
+	builder->get_widget("button_epg_next_day", button);
+	button->signal_clicked().connect(sigc::mem_fun(*this, &GtkEpgWidget::next_day));
+
 	builder->get_widget("label_epg_page", label_epg_page);
 	builder->get_widget("spin_button_epg_page", spin_button_epg_page);
 	spin_button_epg_page->signal_changed().connect(sigc::mem_fun(*this, &GtkEpgWidget::on_spin_button_epg_page_changed));
@@ -53,12 +59,7 @@ GtkEpgWidget::GtkEpgWidget(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Buil
 
 void GtkEpgWidget::set_offset(gint value)
 {
-	if (value < 0)
-	{
-		value = 0;
-	}
 	offset = value;
-
 	update();
 }
 
@@ -72,6 +73,16 @@ void GtkEpgWidget::next()
 	set_offset(offset + (epg_span_hours*60*60));
 }
 
+void GtkEpgWidget::previous_day()
+{
+	set_offset(offset - (24*60*60));
+}
+
+void GtkEpgWidget::next_day()
+{
+	set_offset(offset + (24*60*60));
+}
+
 void GtkEpgWidget::on_spin_button_epg_page_changed()
 {	
 	update_table();
@@ -144,11 +155,8 @@ void GtkEpgWidget::update_table()
 
 		Gtk::Widget* widget = NULL;
 
-		builder->get_widget("button_epg_previous", widget);
-		widget->set_sensitive(offset > 0);
-		
 		builder->get_widget("button_epg_now", widget);
-		widget->set_sensitive(offset > 0);
+		widget->set_sensitive(offset != 0);
 		
 		ChannelArray& channels = channel_manager.get_channels();
 
@@ -210,7 +218,7 @@ void GtkEpgWidget::update_table()
 }
 
 void GtkEpgWidget::create_channel_row(Gtk::RadioButtonGroup& group, Channel& channel,
-	guint table_row, gboolean selected, guint start_time, guint channel_number,
+	guint table_row, gboolean selected, time_t start_time, guint channel_number,
 	gboolean show_channel_number, gboolean show_epg_time, gboolean show_epg_tooltips)
 {
 	Glib::ustring channel_text = Glib::ustring::compose("<b>%1</b>", encode_xml(channel.name));
@@ -243,7 +251,7 @@ void GtkEpgWidget::create_channel_row(Gtk::RadioButtonGroup& group, Channel& cha
 	);
 	
 	guint total_number_columns = 0;
-	guint end_time = start_time + epg_span_hours*60*60;
+	time_t end_time = start_time + epg_span_hours*60*60;
 	guint last_event_end_time = 0;
 	guint number_columns = epg_span_hours * COLUMNS_PER_HOUR + 1;
 
