@@ -91,7 +91,6 @@ MainWindow::MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 	engine						= NULL;
 	output_fd					= -1;
 	mute_state					= false;
-	screensaver_inhibit_cookie	= 0;
 	
 	is_cursor_visible = true;
 	gchar     bits[] = {0};
@@ -102,6 +101,9 @@ MainWindow::MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 	add_accel_group(ui_manager->get_accel_group());
 	ui_manager->add_ui_from_string(ui_info);
 
+	builder->get_widget("label_time", label_time);
+	label_time->hide();
+
 	builder->get_widget("drawing_area_video", drawing_area_video);
 	drawing_area_video->set_double_buffered(false);
 	drawing_area_video->signal_expose_event().connect(sigc::mem_fun(*this, &MainWindow::on_drawing_area_expose_event));
@@ -275,6 +277,7 @@ bool MainWindow::on_motion_notify_event(GdkEventMotion* event_motion)
 void MainWindow::unfullscreen(gboolean restore_mode)
 {
 	Gtk::Window::unfullscreen();
+	label_time->hide();
 	
 	if (restore_mode)
 	{
@@ -289,6 +292,7 @@ void MainWindow::fullscreen(gboolean change_mode)
 	{
 		set_view_mode(VIEW_MODE_VIDEO);
 	}
+	label_time->show();
 	
 	Gtk::Window::fullscreen();
 }
@@ -310,7 +314,9 @@ void MainWindow::on_timeout()
 	try
 	{
 		guint now = time(NULL);
-	
+
+		label_time->set_text(get_local_time_text(now,"%H:%M"));
+		
 		if (channel_change_timeout > 1)
 		{
 			channel_change_timeout--;
@@ -567,8 +573,6 @@ void MainWindow::play(const Glib::ustring& mrl)
 		create_engine();
 	}
 
-	Glib::ustring preferred_language = configuration_manager.get_string_value("preferred_language");
-
 	Gtk::Menu* audio_streams_menu = ((Gtk::MenuItem*)ui_manager->get_widget("/menu_bar/action_audio/action_audio_streams"))->get_submenu();
 	Gtk::Menu* subtitle_streams_menu = ((Gtk::MenuItem*)ui_manager->get_widget("/menu_bar/action_video/action_subtitle_streams"))->get_submenu();
 	
@@ -610,12 +614,6 @@ void MainWindow::play(const Glib::ustring& mrl)
 			)
 		);
 
-		if (!preferred_language.empty() && (preferred_language == audio_stream.language) && !selected)
-		{
-			menu_item->set_active(true);
-			selected = true;
-		}
-
 		count++;
 	}
 
@@ -652,19 +650,12 @@ void MainWindow::play(const Glib::ustring& mrl)
 			)
 		);
 		
-		if (!preferred_language.empty() && (preferred_language == subtitle_stream.language) && !selected)
-		{
-			menu_item->set_active(true);
-			selected = true;
-		}
-
 		count++;
 	}
 
 	if (engine != NULL)
 	{			
 		engine->play(mrl);
-		inhibit_screensaver(true);
 	}
 }
 
@@ -692,6 +683,7 @@ void MainWindow::set_status_text(const Glib::ustring& text)
 	Gtk::Label* label = NULL;
 	builder->get_widget("label_status_text", label);
 	label->set_text(text);
+	label->set_tooltip_text(text);
 }
 
 void MainWindow::start_engine()
@@ -708,7 +700,6 @@ void MainWindow::stop_engine()
 
 	if (engine != NULL)
 	{
-		inhibit_screensaver(false);
 		engine->stop();
 		delete engine;
 		engine = NULL;
@@ -838,12 +829,16 @@ void MainWindow::on_fullscreen()
 
 void MainWindow::show_error(const Glib::ustring& message)
 {
+	set_status_text(message);
+
+	/*
 	g_debug("Message Dialog: '%s'", message.c_str());
 	
 	Gtk::MessageDialog dialog(*this, message, false, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true);
 	dialog.set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 	dialog.set_title(PACKAGE_NAME " - Error");
 	dialog.run();
+	*/
 }
 
 void MainWindow::on_exception()
@@ -866,86 +861,6 @@ void MainWindow::on_exception()
 	}
 }
 
-void MainWindow::inhibit_screensaver(gboolean activate)
-{
-	GError*	error = NULL;
-
-	if (no_screensaver_inhibit)
-	{
-		if (activate)
-		{
-			g_debug("Screensaver inhibit disabled");
-		}
-		return;
-	}
-
-	if (get_application().get_dbus_connection() == NULL)
-	{
-		g_debug("No DBus connection, can't (un)inhibit");
-	}
-	else
-	{
-		try
-		{
-			DBusGProxy* proxy = dbus_g_proxy_new_for_name(get_application().get_dbus_connection(),
-				"org.gnome.ScreenSaver",
-				"/org/gnome/ScreenSaver",
-				"org.gnome.ScreenSaver");
-
-			if (proxy == NULL)
-			{
-				throw Exception("Failed to get org.gnome.ScreenSaver proxy");
-			}
-
-			if (activate)
-			{
-				if (screensaver_inhibit_cookie != 0)
-				{
-					g_debug("Screensaver is already being inhibited");
-				}
-				else
-				{
-					if (!dbus_g_proxy_call(proxy, "Inhibit", &error,
-						G_TYPE_STRING, PACKAGE_NAME, G_TYPE_STRING, "Watching TV", G_TYPE_INVALID,
-						G_TYPE_UINT, &screensaver_inhibit_cookie, G_TYPE_INVALID))
-					{
-						throw Exception("Failed to call Inhibit method");
-					}
-	
-					g_debug("Got screensaver inhibit cookie: %d", screensaver_inhibit_cookie);
-					g_debug("Screensaver inhibited");
-				}
-			}
-			else
-			{
-				if (screensaver_inhibit_cookie == 0)
-				{
-					g_debug("Screensaver is not currently inhibited");
-				}
-				else
-				{
-					if (!dbus_g_proxy_call(proxy, "UnInhibit", &error,
-						G_TYPE_UINT, &screensaver_inhibit_cookie, G_TYPE_INVALID, G_TYPE_INVALID))
-					{
-						throw Exception("Failed to call UnInhibit method");
-					}
-					screensaver_inhibit_cookie = 0;
-
-					g_debug("Screensaver uninhibited");
-				}
-			}
-		}
-		catch (const Exception& exception)
-		{
-			Glib::ustring message = Glib::ustring::compose(_(
-				"An error occurred while trying to communicate with the GNOME screensaver. " \
-				"To stop this message from displaying you can use the --no-screensaver-inhibit " \
-			    "command line option.  The error message was '%1'"), exception.what());
-			show_error(message);
-		}
-	}
-}
-
 void MainWindow::select_channel_to_play()
 {
 	ChannelArray& channels = channel_manager.get_channels();
