@@ -38,6 +38,8 @@ void ScheduledRecordingManager::load(Data::Connection& connection)
 	Glib::ustring where = Glib::ustring::compose(
 		"((start_time + duration) > %1 OR recurring_type != 0)", time(NULL));
 	Data::DataTable data_table = adapter.select_rows(where, "start_time");
+
+	dirty = false;
 	
 	scheduled_recordings.clear();
 	for (Data::Rows::iterator i = data_table.rows.begin(); i != data_table.rows.end(); i++)
@@ -55,9 +57,11 @@ void ScheduledRecordingManager::load(Data::Connection& connection)
 		scheduled_recording.device					= row["device"].string_value;
 
 		scheduled_recordings.push_back(scheduled_recording);
+
+		guint now = time(NULL);
+		if(scheduled_recording.start_time + scheduled_recording.duration < now)
+			dirty = true;
 	}
-	
-	dirty = false;
 
 	g_debug("Scheduled recordings loaded");
 }
@@ -69,6 +73,7 @@ void ScheduledRecordingManager::save(Data::Connection& connection)
 		g_debug("Scheduled recordings are not dirty, not saving");
 		return;
 	}
+	g_debug("Scheduled recordings are dirty, saving");
 	
 	Glib::RecMutex::Lock lock(mutex);
 
@@ -79,7 +84,7 @@ void ScheduledRecordingManager::save(Data::Connection& connection)
 	for (ScheduledRecordingList::iterator i = scheduled_recordings.begin(); i != scheduled_recordings.end(); i++)
 	{
 		ScheduledRecording& scheduled_recording = *i;
-		guint now = time(NULL);
+		time_t now = time(NULL);
 		if (scheduled_recording.get_end_time() > now || scheduled_recording.recurring_type != 0)
 		{
 			Data::Row row;
@@ -111,7 +116,7 @@ void ScheduledRecordingManager::save(Data::Connection& connection)
 	for (Data::Rows::iterator i = data_table.rows.begin(); i != data_table.rows.end(); i++)
 	{
 		Data::Row& row = *i;
-		g_message("ScheduledRecordingManager::save/clear ID: %d", row["scheduled_recording_id"].int_value); 
+		g_debug("ScheduledRecordingManager::save/clear ID: %d", row["scheduled_recording_id"].int_value); 
 
 		if(row["recurring_type"].int_value == SCHEDULED_RECORDING_RECURRING_TYPE_EVERYDAY)
 		{
@@ -157,14 +162,16 @@ void ScheduledRecordingManager::set_scheduled_recording(EpgEvent& epg_event)
 	Application& application = get_application();
 	guint before = configuration_manager.get_int_value("record_extra_before");
 	guint after = configuration_manager.get_int_value("record_extra_after");
+
+	guint now = get_local_time();
 	
-	scheduled_recording.channel_id				= epg_event.channel_id;
-	scheduled_recording.description				= epg_event.get_title();
-	scheduled_recording.recurring_type			= SCHEDULED_RECORDING_RECURRING_TYPE_ONCE;
-	scheduled_recording.action_after			= SCHEDULED_RECORDING_ACTION_AFTER_NONE;
-	scheduled_recording.start_time				= convert_to_utc_time(epg_event.start_time - (before * 60));
-	scheduled_recording.duration				= epg_event.duration + ((before + after) * 60);
-	scheduled_recording.device					= "";
+	scheduled_recording.channel_id		= epg_event.channel_id;
+	scheduled_recording.description		= epg_event.get_title();
+	scheduled_recording.recurring_type	= SCHEDULED_RECORDING_RECURRING_TYPE_ONCE;
+	scheduled_recording.action_after	= SCHEDULED_RECORDING_ACTION_AFTER_NONE;
+	scheduled_recording.start_time		= convert_to_utc_time(epg_event.start_time - (before * 60));
+ 	scheduled_recording.duration		= epg_event.duration + ((before + after) * 60);	
+	scheduled_recording.device			= "";
 	
 	set_scheduled_recording(scheduled_recording);
 }
@@ -247,7 +254,10 @@ void ScheduledRecordingManager::set_scheduled_recording(ScheduledRecording& sche
 
 		if (scheduled_recording.device.empty())
 		{
-			throw Exception(_("Failed to set scheduled recording: There are no devices available at that time"));
+			Glib::ustring message = Glib::ustring::compose(_(
+				"Failed to set scheduled recording for '%1' at %2: There are no devices available at that time"),
+				scheduled_recording.description, scheduled_recording.get_start_time_text());
+			throw Exception(message);
 		}
 
 		g_debug("Device selected: '%s'", scheduled_recording.device.c_str());
@@ -316,6 +326,7 @@ void ScheduledRecordingManager::set_scheduled_recording(ScheduledRecording& sche
 		current.channel_id = scheduled_recording.channel_id;
 		current.start_time = scheduled_recording.start_time;
 		current.duration = scheduled_recording.duration;
+		dirty = true;
 	}
 	
 	// If the scheduled recording is new then add it
@@ -382,30 +393,35 @@ void ScheduledRecordingManager::remove_scheduled_recording(EpgEvent& epg_event)
 	}	
 }
 
-guint scheduled_recording_now = 0;
-
-guint is_old(ScheduledRecording& scheduled_recording)
-{
-	return (scheduled_recording.get_end_time() < scheduled_recording_now && scheduled_recording.recurring_type == SCHEDULED_RECORDING_RECURRING_TYPE_ONCE);
-}
-
 ScheduledRecordingList ScheduledRecordingManager::check_scheduled_recordings()
 {
 	ScheduledRecordingList results;
 	
+	time_t now = time(NULL);
+
 	g_debug("Checking scheduled recordings");
 	Glib::RecMutex::Lock lock(mutex);
 
-	Application& application = get_application();
-
-	scheduled_recording_now = time(NULL);
-	g_debug("Removing scheduled recordings older than %d", scheduled_recording_now);
-	scheduled_recordings.remove_if(is_old);
-
+	g_debug("Now: %u", (guint)now);
+	g_debug("Removing scheduled recordings older than %u", (guint)now);
+	
+	ScheduledRecordingList::iterator i = scheduled_recordings.begin();
+	while (i != scheduled_recordings.end())
+	{
+		if ((*i).is_old(now))
+		{
+			guint action = (*i).action_after;
+			i = scheduled_recordings.erase(i);
+			action_after(action);
+		}
+		else
+		{
+			i++;
+		}
+	}
+	
 	if (!scheduled_recordings.empty())
 	{
-		guint now = time(NULL);
-		g_debug("Now: %d", now);
 		g_debug("=============================================================================================");
 		g_debug("#ID | Start Time | Duration | Record | Channel    | Device                      | Description");
 		g_debug("=============================================================================================");
@@ -414,9 +430,9 @@ ScheduledRecordingList ScheduledRecordingManager::check_scheduled_recordings()
 			ScheduledRecording& scheduled_recording = *i;
 				
 			gboolean record = scheduled_recording.is_in(now);
-			g_debug("%3d | %d | %8d | %s | %10s | %27s | %s",
+			g_debug("%3d | %u | %8d | %s | %10s | %27s | %s",
 				scheduled_recording.scheduled_recording_id,
-				scheduled_recording.start_time,
+				(guint)scheduled_recording.start_time,
 				scheduled_recording.duration,
 				record ? "true  " : "false ",
 				channel_manager.get_channel_by_id(scheduled_recording.channel_id).name.c_str(),
@@ -427,6 +443,11 @@ ScheduledRecordingList ScheduledRecordingManager::check_scheduled_recordings()
 			{
 				results.push_back(scheduled_recording);
 			}
+			
+			if (scheduled_recording.get_end_time() < now)
+			{
+				dirty = true;
+			}
 		}
 	}
 		
@@ -467,11 +488,7 @@ guint ScheduledRecordingManager::is_recording(const Channel& channel)
 		ScheduledRecording& scheduled_recording = *i;
 		if (scheduled_recording.is_in(now) && scheduled_recording.channel_id == channel.channel_id)
 		{
-			return -1;
-		}
-		else if (scheduled_recording.is_in(now-60) && scheduled_recording.channel_id == channel.channel_id)
-		{
-			return scheduled_recording.action_after;
+			return scheduled_recording.scheduled_recording_id;
 		}
 	}
 	return 0;
@@ -495,3 +512,39 @@ gboolean ScheduledRecordingManager::is_recording(const EpgEvent& epg_event)
 	
 	return false;
 }
+
+void ScheduledRecordingManager::action_after(guint action)
+{
+	if (action == SCHEDULED_RECORDING_ACTION_AFTER_CLOSE)
+	{
+		g_message("Me TV closed by Scheduled Recording");
+		action_quit->activate();
+	}
+	else if (action == SCHEDULED_RECORDING_ACTION_AFTER_SHUTDOWN)
+	{
+		DBusGConnection* dbus_connection = get_application().get_dbus_connection();
+		if (dbus_connection == NULL)
+		{
+			throw Exception(_("DBus connection not available"));
+		}
+		
+		g_message("Computer shutdown by scheduled recording");
+		
+		DBusGProxy* proxy = dbus_g_proxy_new_for_name(dbus_connection,
+			"org.gnome.SessionManager",
+			"/org/gnome/SessionManager",
+			"org.gnome.SessionManager");
+		if (proxy == NULL)
+		{
+			throw Exception(_("Failed to get org.gnome.SessionManager proxy"));
+		}
+		
+		GError* error = NULL;
+		if (!dbus_g_proxy_call(proxy, "Shutdown", &error, G_TYPE_INVALID, G_TYPE_INVALID))
+		{
+			throw Exception(_("Failed to call Shutdown method"));
+		}
+
+		g_message("Shutdown requested");
+	}
+}
