@@ -21,12 +21,12 @@
 #ifndef __SCHEDULED_RECORDINGS_DIALOG_H__
 #define __SCHEDULED_RECORDINGS_DIALOG_H__
 
-#include <libgnomeuimm.h>
+#include <gtkmm.h>
 #include "data.h"
 
 class ScheduledRecordingsDialog : public Gtk::Dialog
 {
-private:	
+private:
 	class ModelColumns : public Gtk::TreeModel::ColumnRecord
 	{
 	public:
@@ -38,6 +38,8 @@ private:
 			add(column_channel);
 			add(column_start_time);
 			add(column_duration);
+			add(column_recurring_type);
+			add(column_action_after);
 			add(column_device);
 		}
 
@@ -47,6 +49,8 @@ private:
 		Gtk::TreeModelColumn<Glib::ustring>	column_channel;
 		Gtk::TreeModelColumn<Glib::ustring>	column_start_time;
 		Gtk::TreeModelColumn<Glib::ustring>	column_duration;
+		Gtk::TreeModelColumn<Glib::ustring>	column_recurring_type;
+		Gtk::TreeModelColumn<Glib::ustring>	column_action_after;
 		Gtk::TreeModelColumn<Glib::ustring>	column_device;
 	};
 	
